@@ -2,8 +2,6 @@
 ( cd usr/lib ; ln -sf libsvn_fs_base-1.so.0.0.0 libsvn_fs_base-1.so )
 ( cd usr/lib ; rm -rf libsvn_repos-1.so )
 ( cd usr/lib ; ln -sf libsvn_repos-1.so.0.0.0 libsvn_repos-1.so )
-( cd usr/lib ; rm -rf libneon.so )
-( cd usr/lib ; ln -sf libneon.so.25.0.5 libneon.so )
 ( cd usr/lib ; rm -rf libsvn_ra-1.so )
 ( cd usr/lib ; ln -sf libsvn_ra-1.so.0.0.0 libsvn_ra-1.so )
 ( cd usr/lib ; rm -rf libsvn_diff-1.so )
@@ -42,8 +40,6 @@
 ( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so )
 ( cd usr/lib ; rm -rf libsvn_fs-1.so )
 ( cd usr/lib ; ln -sf libsvn_fs-1.so.0.0.0 libsvn_fs-1.so )
-( cd usr/lib ; rm -rf libneon.so.25 )
-( cd usr/lib ; ln -sf libneon.so.25.0.5 libneon.so.25 )
 ( cd usr/lib ; rm -rf libsvn_subr-1.so.0 )
 ( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so.0 )
 ( cd usr/lib ; rm -rf libsvn_diff-1.so.0 )
